==> dagr-vebchar-0.5.1-sources.jar: META-INF/resources/lifebuoy/SHAKUNTALA-USER-GUIDE.md <==
## 1. summary

Lorem ipsum dolor sit amet, tritani oblique intellegam ut quo, te postea labitur his. Cu eam omnis inciderint, causae meliore corrumpit no vix. Convenire mediocrem patrioque et duo, affert sanctus te mel. Mundi feugiat vix ex, quod persius his id.

Ex justo atomorum necessitatibus usu, id posse dicta platonem sea. Omnis iuvaret eruditi vel in. Pri oblique detracto elaboraret id. Aeterno labitur scripserit ut eum, sit velit paulo inimicus ex.

Nec idque mediocrem te, mea summo volutpat at. Sea at nobis commodo deseruisse. Vis albucius oportere at. At wisi mutat affert nec, est falli veniam ne. Ne regione consulatu sea, idque feugiat ea vis. Ne postea quaeque per, graece numquam quaestio quo ex.

## 2. requirements

<span>

| maven | >= | __3.3.1__ |
|-------|----|-----------|
| java  | >= | __1.8__   |

</span>

## 3. maven central

[![Maven Central](https://maven-badges.herokuapp.com/maven-central/net.aequologica.neo/shakuntala/badge.svg?style=flat)](http://search.maven.org/#search|ga|1|net.aequologica.neo/shakuntala)

<span id="latest_shakuntala">
  <img class="ajaxLoading" style="display:none; cursor:pointer;" title="refresh version" >
  version <span id="download"><span id="version">x.y.z</span></span>
  of <span class="gav">
     <span style="display:none">
       <span id="group">net.aequologica.neo</span>
       <span>:</span>
     </span>
     <span id="artifact">shakuntala-core</span>
     <span>.</span>
     <span id="packaging">jar</span>
  </span>
  is in <span class="server">&#x2026;</span>
</span>

(for information only, since maven 3.3.1 there is no need anymore to download shakuntala manually)

## 4. installation

shakuntala is a __maven extension__ implementing the __event spy interface__.

Since maven version 3.3.1, "_Core Extension mechanism has been improved to make it simpler to use_" cf. [Apache Maven 3.3.1 Features](http://blog.soebes.de/blog/2015/03/17/apache-maven-3-dot-3-1-features/)

"_So you can define an `\${maven.projectBasedir}/.mvn/extensions.xml` file which looks like:_"

    <extensions xmlns="http://maven.apache.org/EXTENSIONS/1.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
      xsi:schemaLocation="http://maven.apache.org/EXTENSIONS/1.0.0 http://maven.apache.org/xsd/core-extensions-1.0.0.xsd">
      <extension>
        <groupId>net.aequologica.neo</groupId>
        <artifactId>shakuntala-core</artifactId>
        <version>x.y.z</version>
      </extension>
    </extensions>

## 5. first time configuration

cd to `\${maven.projectBasedir}`, and launch a maven command, e.g. `mvn help:help` or `maven validate`. 

First invocation will create (if it does not exists) a configuration file with default settings (cf. below) named `shakuntala.conf` in the `.mvn` subdirectory:

## 6. configuration reference

Shakuntala looks for a configuration file in the 5 locations below, in this order. First file found wins.

### a. global environment 

If the environment variable `SHAKUNTALA_CONF` exists, and if it contains a valid path, and if a file exists at this path. THe file can have any name. 

### b. project 

`\${maven.projectBasedir}/.mvn/shakuntala.conf` on the file system

### c. classpath

`/.shakuntala/conf/application.conf` on the classpath.

### d. user

`$user.home/.shakuntala/conf/application.conf` on the file system

### e. default
A default configuration file is embedded in shakuntala-core.jar, and is copied verbatim on first invocation to
`$user.home/.shakuntala/conf/` if nothing exists already at this location.

###### <span id="shakuntala_default_configuration_url">default configuration file</span>

<pre class="shakuntala_default_configuration_file"></pre>

==> dagr-vebchar-0.5.2-sources.jar: META-INF/resources/lifebuoy/SHAKUNTALA-USER-GUIDE.md <==
## 1. summary

Lorem ipsum dolor sit amet, tritani oblique intellegam ut quo, te postea labitur his. Cu eam omnis inciderint, causae meliore corrumpit no vix. Convenire mediocrem patrioque et duo, affert sanctus te mel. Mundi feugiat vix ex, quod persius his id.

Ex justo atomorum necessitatibus usu, id posse dicta platonem sea. Omnis iuvaret eruditi vel in. Pri oblique detracto elaboraret id. Aeterno labitur scripserit ut eum, sit velit paulo inimicus ex.

Nec idque mediocrem te, mea summo volutpat at. Sea at nobis commodo deseruisse. Vis albucius oportere at. At wisi mutat affert nec, est falli veniam ne. Ne regione consulatu sea, idque feugiat ea vis. Ne postea quaeque per, graece numquam quaestio quo ex.

## 2. requirements

<span>

| maven | >= | __3.3.1__ |
|-------|----|-----------|
| java  | >= | __1.8__   |

</span>

## 3. maven central

[![Maven Central](https://maven-badges.herokuapp.com/maven-central/net.aequologica.neo/shakuntala/badge.svg?style=flat)](http://search.maven.org/#search|ga|1|net.aequologica.neo/shakuntala)

<span id="latest_shakuntala">
  <button class="btn btn-outline-secondary btn-sm">
      <i class="ajaxLoading shaky fas fa-sync" style="display:none; cursor:pointer;" title="refresh version" ></i>
  </button>
  version <span id="download"><span id="version">&hellip</span></span>
  of <span class="gav">
     <span style="display:none">
       <span id="group">net.aequologica.neo</span>
       <span>:</span>
     </span>
     <span id="artifact">shakuntala-core</span>
     <span>.</span>
     <span id="packaging">jar</span>
  </span>
  is in <span class="server">&#x2026;</span>
</span>

(for information only, since maven 3.3.1 there is no need anymore to download shakuntala manually)

## 4. installation

shakuntala is a __maven extension__ implementing the __event spy interface__.

Since maven version 3.3.1, "_Core Extension mechanism has been improved to make it simpler to use_" cf. [Apache Maven 3.3.1 Features](http://blog.soebes.de/blog/2015/03/17/apache-maven-3-dot-3-1-features/)

"_So you can define an `\${maven.projectBasedir}/.mvn/extensions.xml` file which looks like:_"

    <extensions xmlns="http://maven.apache.org/EXTENSIONS/1.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
      xsi:schemaLocation="http://maven.apache.org/EXTENSIONS/1.0.0 http://maven.apache.org/xsd/core-extensions-1.0.0.xsd">
      <extension>
        <groupId>net.aequologica.neo</groupId>
        <artifactId>shakuntala-core</artifactId>
        <version>x.y.z</version>
      </extension>
    </extensions>

## 5. first time configuration

cd to `\${maven.projectBasedir}`, and launch a maven command, e.g. `mvn help:help` or `maven validate`. 

First invocation will create (if it does not exists) a configuration file with default settings (cf. below) named `shakuntala.conf` in the `.mvn` subdirectory:

## 6. configuration reference

Shakuntala looks for a configuration file in the 5 locations below, in this order. First file found wins.

### a. global environment 

If the environment variable `SHAKUNTALA_CONF` exists, and if it contains a valid path, and if a file exists at this path. THe file can have any name. 

### b. project 

`\${maven.projectBasedir}/.mvn/shakuntala.conf` on the file system

### c. classpath

`/.shakuntala/conf/application.conf` on the classpath.

### d. user

`$user.home/.shakuntala/conf/application.conf` on the file system

### e. default
A default configuration file is embedded in shakuntala-core.jar, and is copied verbatim on first invocation to
`$user.home/.shakuntala/conf/` if nothing exists already at this location.

###### <span id="shakuntala_default_configuration_url">default configuration file</span>

<pre class="shakuntala_default_configuration_file"></pre>
